@@ -3,15 +3,14 @@ import time
 import sys
 import httpx
 import requests
-import string
-import os
 import mechanize
+import string
 import json as _json
 from httpx import AsyncClient
 from datetime import datetime
 from bs4 import BeautifulSoup
 from collections.abc import Iterable
-from webeye.rot import encoding
+from webeye.encryptions.rot import encoding
 from typing import Union
 from concurrent.futures import ThreadPoolExecutor
 
@@ -272,6 +271,18 @@ def fetch_dns(host: str, cli=False) -> Union[None, list]:
     except KeyboardInterrupt:
         return sys.exit('Stopped, Exiting: 1')
 
+def isitdown(host: str) -> dict:
+    """Check whether the site is down for everyone or not..."""
+    try:
+        response = requests.get(f'https://isitdown.site/api/v3/{host}').json()
+        return response
+    except requests.ConnectionError:
+        return 'Connection Lost: Exiting...'
+    except requests.ConnectTimeout:
+        return 'Unable to Get Response'
+    except KeyboardInterrupt:
+        return sys.exit('Stopped, Exiting: 1')
+
 def is_honeypot(host: str, score: bool=False):
     '''Return Probablity of Honeypot between [0.0 - 1.0] based on Shodan Honeyscore...'''
     try:
@@ -325,6 +336,19 @@ class AsyncHelper:
             else:
                 return response
 
+    async def isitdown(self, host: str) -> dict:
+        """Asynchronously checks whether the site is down for everyone or not."""
+        try:
+            async with AsyncClient() as session:
+                response = await session.get(f'https://isitdown.site/api/v3/{host}')
+                return response.json()
+        except httpx.ConnectError:
+            return 'Connection Lost: Retry Again'
+        except httpx.ConnectTimeout:
+            return 'Taking too long! Exiting: 1'
+        except KeyboardInterrupt:
+            return sys.exit('Stopped, Exiting: 1')
+
     async def reversedns(self, hostip: str) -> str:
         '''Asynchronous Reverse DNS Lookup'''
         async with AsyncClient() as session:
@@ -393,6 +417,8 @@ class AsyncHelper:
                 RESPONSE = []
                 api = await session.get(f"https://api.hackertarget.com/hostsearch/?q={host}")
                 lines = api.text.split("\n")
+                if '' in lines:
+                    lines.remove('')
                 if cli:
                     cliresponse = []
                     for x in lines:
@@ -561,9 +587,3 @@ class AsyncHelper:
             return f'{socket.gethostbyname(host)} is Unreachable'
         except KeyboardInterrupt:
             return sys.exit('Stopped, Exiting: 1')
-
-
-
-# helper = AsyncHelper()
-# import asyncio
-# print(asyncio.run(helper.find_subdomains('zaeemtechnical.ml')))
